@@ -344,8 +344,10 @@ class AccountDialog(object):
 class SMSEntryWindow(object):
 
 	MAX_CHAR = 160
+	_SENTINEL_ICON = QtGui.QIcon()
 
 	def __init__(self, parent, app, session, errorLog):
+		self._app = app
 		self._session = session
 		self._session.draft.recipientsChanged.connect(self._on_recipients_changed)
 
@@ -365,6 +367,7 @@ class SMSEntryWindow(object):
 		self._targetLayout = QtGui.QVBoxLayout()
 		self._targetList = QtGui.QWidget()
 		self._targetList.setLayout(self._targetLayout)
+		self._closeIcon = qui_utils.get_theme_icon(("window-close", "general_close", "gtk-close"), self._SENTINEL_ICON)
 		self._history = QtGui.QLabel()
 		self._history.setTextFormat(QtCore.Qt.RichText)
 		self._history.setWordWrap(True)
@@ -386,7 +389,7 @@ class SMSEntryWindow(object):
 		self._scrollEntry.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
 		self._scrollEntry.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
 
-		self._characterCountLabel = QtGui.QLabel("0 (0)")
+		self._characterCountLabel = QtGui.QLabel("")
 		self._singleNumberSelector = QtGui.QComboBox()
 		self._singleNumbersCID = None
 		self._singleNumberSelector.activated.connect(self._on_single_change_number)
@@ -419,6 +422,7 @@ class SMSEntryWindow(object):
 		qui_utils.set_stackable(self._window, True)
 		self._window.setWindowTitle("Contact")
 		self._window.setCentralWidget(centralWidget)
+		self._window.addAction(self._app.orientationAction)
 
 		self._closeWindowAction = QtGui.QAction(None)
 		self._closeWindowAction.setText("Close")
@@ -437,12 +441,20 @@ class SMSEntryWindow(object):
 		self._scrollTimer.timeout.connect(self._on_delayed_scroll_to_bottom)
 
 		self._window.show()
+		self._update_letter_count()
 		self._update_target_fields()
 
 	def close(self):
 		self._window.destroy()
 		self._window = None
 
+	def set_orientation(self, isPortrait):
+		if isPortrait:
+			qui_utils.set_window_orientation(self._window, QtCore.Qt.Vertical)
+		else:
+			qui_utils.set_window_orientation(self._window, QtCore.Qt.Horizontal)
+		self._scrollTimer.start()
+
 	def _update_letter_count(self):
 		count = self._smsEntry.toPlainText().size()
 		numTexts, numCharInText = divmod(count, self.MAX_CHAR)
@@ -507,9 +519,18 @@ class SMSEntryWindow(object):
 				numbers = self._session.draft.get_numbers(cid)
 
 				titleLabel = QtGui.QLabel(title)
+				titleLabel.setWordWrap(True)
 				numberSelector = QtGui.QComboBox()
 				self._populate_number_selector(numberSelector, cid, numbers)
-				deleteButton = QtGui.QPushButton("Delete")
+				if self._closeIcon is self._SENTINEL_ICON:
+					deleteButton = QtGui.QPushButton("Delete")
+				else:
+					deleteButton = QtGui.QPushButton(self._closeIcon, "")
+				deleteButton.setSizePolicy(QtGui.QSizePolicy(
+					QtGui.QSizePolicy.Minimum,
+					QtGui.QSizePolicy.Minimum,
+					QtGui.QSizePolicy.PushButton,
+				))
 				callback = functools.partial(
 					self._on_remove_contact,
 					cid
@@ -518,9 +539,9 @@ class SMSEntryWindow(object):
 				deleteButton.clicked.connect(callback)
 
 				rowLayout = QtGui.QHBoxLayout()
-				rowLayout.addWidget(titleLabel)
-				rowLayout.addWidget(numberSelector)
-				rowLayout.addWidget(deleteButton)
+				rowLayout.addWidget(titleLabel, 1000)
+				rowLayout.addWidget(numberSelector, 0)
+				rowLayout.addWidget(deleteButton, 0)
 				rowWidget = QtGui.QWidget()
 				rowWidget.setLayout(rowLayout)
 				self._targetLayout.addWidget(rowWidget)
